@@ -32,9 +32,8 @@ class GIN(tf.keras.Model):
         """
 
         if len(inputs) == 3:
-            x, edge_index, edge_weight = inputs
+            x, edge_index, _ = inputs
         else:
             x, edge_index = inputs
-            edge_weight = None
 
-        return gin(x, edge_index, edge_weight, self.mlp_model, self.eps, training=training)
+        return gin(x, edge_index, self.mlp_model, self.eps, training=training)
